@@ -2,11 +2,11 @@ from .data import *
 from .models import *
 from .plotters import *
 from .trainers import *
-from .logger import *
+from .logger import Logger
 
 from .metrics import *
 from .callbacks import *
 
 from .utils import parse_arguments, make_path
 
-VERSION = "0.0.2.8"
+VERSION = "0.0.2.9"
